==> process-optaplanner-springboot-1.4.1.Final-sources.jar: org/kie/kogito/handlers/FlightService_createFlight_8_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionException;

@org.springframework.stereotype.Component()
public class FlightService_createFlight_8_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.kogito.examples.service.FlightService service;

    public FlightService_createFlight_8_Handler() {
        this(new org.kie.kogito.examples.service.FlightService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public FlightService_createFlight_8_Handler(org.kie.kogito.examples.service.FlightService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        java.lang.Object result;
        try {
            result = service.createFlight((org.kie.kogito.examples.domain.FlightDTO) workItem.getParameter("flightParams"));
        } catch (java.lang.IllegalArgumentException ex) {
            throw new WorkItemExecutionException("500", ex);
        }
        workItemManager.completeWorkItem(workItem.getStringId(), java.util.Collections.singletonMap("flight", result));
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.kogito.examples.service.FlightService_createFlight_8_Handler";
    }
}

==> process-optaplanner-springboot-1.18.0.Final-sources.jar: org/kie/kogito/handlers/FlightService_createFlight_8_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionException;

@org.springframework.stereotype.Component()
public class FlightService_createFlight_8_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.kogito.examples.service.FlightService service;

    public FlightService_createFlight_8_Handler() {
        this(new org.kie.kogito.examples.service.FlightService());
    }

    @org.springframework.beans.factory.annotation.Autowired(required = false)
    @org.springframework.context.annotation.Lazy()
    public FlightService_createFlight_8_Handler(org.kie.kogito.examples.service.FlightService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        java.lang.Object result;
        try {
            result = service.createFlight((org.kie.kogito.examples.domain.FlightDTO) workItem.getParameter("flightParams"));
        } catch (java.lang.IllegalArgumentException ex) {
            throw new WorkItemExecutionException("500", ex);
        }
        workItemManager.completeWorkItem(workItem.getStringId(), java.util.Collections.singletonMap("flight", result));
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.kogito.examples.service.FlightService_createFlight_8_Handler";
    }
}
